tweedieDistr-package: tweedieDistr: Tweedie Distribution

tweedieDistr-packageR Documentation

tweedieDistr: Tweedie Distribution

Description

logo

Provides density, distribution function, quantile function, and random generation for the Tweedie distribution under the compound Poisson-Gamma parameterisation with power parameter in (1, 2). The density is evaluated using the series expansion of Dunn and Smyth (2005) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}, implemented in C++ via 'Rcpp' and 'RcppArmadillo' for performance. A constructor compatible with the 'distributional' package is also provided for use in tidy modelling workflows.

Author(s)

Maintainer: Stefano Damato stefanodamato128@gmail.com

See Also

Useful links:


tweedieDistr documentation built on July 23, 2026, 5:07 p.m.