| tweedieDistr-package | R Documentation |
Provides density, distribution function, quantile function, and random generation for the Tweedie distribution under the compound Poisson-Gamma parameterisation with power parameter in (1, 2). The density is evaluated using the series expansion of Dunn and Smyth (2005) \Sexpr[results=rd]{tools:::Rd_expr_doi("10.1007/s11222-005-4070-y")}, implemented in C++ via 'Rcpp' and 'RcppArmadillo' for performance. A constructor compatible with the 'distributional' package is also provided for use in tidy modelling workflows.
Maintainer: Stefano Damato stefanodamato128@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.